@@ -23,35 +23,30 @@ class JenkinsRepo(Repo):
         In case of branch retun {branch: _name_}
         In case of pr return {pull_request: _number_}
         """
-
-        name = self.git.name_rev("--name-only", "HEAD")
-        # posible outputs
-        ## local cloned
-        # feature/ADH-1376/ADH-1377 #  branches
-        # tags/0.1.4 #  tags
-        ## jenkins cloned
-        # remotes/origin/feature/ADH-1376/ADH-1378 #   branches
-        # origin/pr/231/head #  pull requests
-        # tags/0.1.4 #  tags
-        reponame = self.remotes.origin.url.split("/")[-1].split(".git")[0]
-        repoowner = self.remotes.origin.url.split("/")[-2].split(".com:")[-1]
-
-        data = {"reponame": reponame, "repoowner": repoowner}
-        if "pipeline" in name:
+        data = {}
+        if os.getenv("GITLAB_CI") == "true":
             reponame = os.getenv("CI_PROJECT_NAME")
+            data.update({"reponame": reponame})
             if os.getenv("CI_PIPELINE_SOURCE") == "merge_request_event":
                 data.update({"pull_request": os.getenv("CI_MERGE_REQUEST_IID")})
             elif os.getenv("CI_COMMIT_TAG"):
-                data.update(
-                    {
-                        "branch": self.get_tagged_branch(
-                            f"tags/{os.getenv('CI_COMMIT_TAG')}"
-                        )
-                    }
-                )
+                data.update({"branch": os.getenv("CI_COMMIT_TAG")})
             else:
                 data.update({"branch": os.getenv("CI_COMMIT_BRANCH")})
         else:
+            name = self.git.name_rev("--name-only", "HEAD")
+            # posible outputs
+            ## local cloned
+            # feature/ADH-1376/ADH-1377 #  branches
+            # tags/0.1.4 #  tags
+            ## jenkins cloned
+            # remotes/origin/feature/ADH-1376/ADH-1378 #   branches
+            # origin/pr/231/head #  pull requests
+            # tags/0.1.4 #  tags
+            reponame = self.remotes.origin.url.split("/")[-1].split(".git")[0]
+            repoowner = self.remotes.origin.url.split("/")[-2].split(".com:")[-1]
+
+            data.update({"reponame": reponame, "repoowner": repoowner})
             # pull request case
             # it works basically on ci with
             # clean git init and fetch remote with +refs/pull/*:refs/origin/pr/*
